import matplotlib.pyplot as plt
import pandas as pd
import numpy as np
from scipy.integrate import trapz

# Read the data from the CSV file
file_path = "co2_bend.txt"

try:
    # Assuming your file has a header, change header=None if it doesn't
    data = pd.read_csv(file_path, header=None, names=['Wavenumber', 'AbsorptionIntensity'])
except FileNotFoundError:
    print(f"Error: File '{file_path}' not found.")
    exit()
except pd.errors.EmptyDataError:
    print(f"Error: File '{file_path}' is empty.")
    exit()

# Plotting absorbance vs wavenumber
plt.figure(figsize=(10, 6))
plt.plot(data['Wavenumber'], data['AbsorptionIntensity'], label='Absorbance vs Wavenumber')

# Adding labels and title
plt.xlabel('Wavenumber')
plt.ylabel('Absorbance')
plt.title('Absorbance vs Wavenumber')
plt.legend()

# Prompt user for CO2 concentration in parts per million (ppm)
co2_ppm = float(input("Enter the CO2 concentration in parts per million (ppm): "))
co2_ppm /= 1e6

xsec_num_density = 234972 * co2_ppm
# Multiply each absorption intensity by 96.8 to obtain relative absorbance (Arel)
data['RelativeAbsorbance'] = data['AbsorptionIntensity'] * xsec_num_density

# Convert relative absorbance to flux transmittance using the provided formula
data['FluxTransmittance'] = (np.exp(-(data['RelativeAbsorbance'] * 2.245)) + np.exp(-(data['RelativeAbsorbance'] * 1.13))) / 2

# Plotting flux transmittance vs wavenumber
#plt.figure(figsize=(10, 6))
#plt.plot(data['Wavenumber'], data['FluxTransmittance'], label='Flux Transmittance vs Wavenumber')

# Adding labels and title
#plt.xlabel('Wavenumber')
#plt.ylabel('Flux Transmittance')
#plt.title('Flux Transmittance vs Wavenumber')
#plt.legend()

# Generate wavenumbers from 0.01 to 2399.99 cm^-1
wvn = np.arange(0.01, 2400, 0.01)

# Calculate Planck distribution for temperature of 288 Kelvin
temp = 288
planck_distribution = (0.000000037211 * wvn**3) / (np.exp(1.435 * wvn / temp) - 1)

# Multiply flux transmittance by Planck distribution at each wavenumber
data['Result'] = data['FluxTransmittance'] * np.interp(data['Wavenumber'], wvn, planck_distribution)

# Plotting the result
plt.figure(figsize=(10, 6))
plt.plot(data['Wavenumber'], data['Result'], label='Result')

# Adding labels and title
plt.xlabel('Wavenumber')
plt.ylabel('Result')
plt.title('Result vs Wavenumber')
plt.legend()

# Integrate the area under the Planck distribution and the product of the Planck curve with flux transmittance
integral_planck = trapz(planck_distribution, wvn)
integral_result = trapz(data['Result'], data['Wavenumber'])

# Print the ratio of the integrated fluxes
ratio = integral_result / integral_planck
print(f"H2O flux transmittance: 0.83")
trans = ratio*0.83
print(f"Product of H2O and CO2 flux transmittance: {trans}")
temp_surf = 255/trans**0.25
print(f"Temperature at earth's surface: {temp_surf}")

# Show the plots
#plt.show()